@@ -19,6 +19,11 @@ setMethod("$",
           "IVW",
           function(x, name) slot(x, name))
 
+#' @rdname getter
+setMethod("$",
+          "MRMBE",
+          function(x, name) slot(x, name))
+
 #' @rdname getter
 setMethod("$",
           "Egger",
@@ -37,4 +42,19 @@ setMethod("$",
 #' @rdname getter
 setMethod("$",
           "MaxLik",
+          function(x, name) slot(x, name))
+
+#' @rdname getter
+setMethod("$",
+          "MVIVW",
+          function(x, name) slot(x, name))
+
+#' @rdname getter
+setMethod("$",
+          "MRMVInput",
+          function(x, name) slot(x, name))
+
+#' @rdname getter
+setMethod("$",
+          "MRHetPen",
           function(x, name) slot(x, name))
\ No newline at end of file
